@@ -37,9 +37,17 @@ const (
 var (
 	FdStatus *os.File
 
-	flagNoStatus = flag.Bool("no-status", false, "disable statusline (REDO_NO_STATUS=1)")
+	flagNoStatus *bool
 )
 
+func init() {
+	cmdName := CmdName()
+	if !(cmdName == CmdNameRedo || cmdName == CmdNameRedoIfchange) {
+		return
+	}
+	flagNoStatus = flag.Bool("no-status", false, "disable statusline (REDO_NO_STATUS=1)")
+}
+
 func statusInit() {
 	if NoProgress || *flagNoStatus {
 		return
